summaryrefslogtreecommitdiffstats
path: root/kio/bookmarks/kbookmarkmanager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kio/bookmarks/kbookmarkmanager.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/bookmarks/kbookmarkmanager.h')
-rw-r--r--kio/bookmarks/kbookmarkmanager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/bookmarks/kbookmarkmanager.h b/kio/bookmarks/kbookmarkmanager.h
index e8fcd6196..403a2e1b3 100644
--- a/kio/bookmarks/kbookmarkmanager.h
+++ b/kio/bookmarks/kbookmarkmanager.h
@@ -57,7 +57,7 @@ class KIO_EXPORT KBookmarkManager : public TQObject, public DCOPObject
protected:
/**
* Creates a bookmark manager with a path to the bookmarks. By
* default, it will use the KDE standard dirs to tqfind and create the
* correct location. If you are using your own app-specific
* bookmarks directory, you must instantiate this class with your
* own path <em>before</em> KBookmarkManager::managerForFile() is ever
@@ -152,10 +152,10 @@ public:
/**
* @return the bookmark designated by @p address
* @param address the address belonging to the bookmark you're looking for
* @param tolerate when true tries to tqfind the most tolerable bookmark position
* @see KBookmark::address
*/
- KBookmark tqfindByAddress( const TQString & address, bool tolerate = false );
+ KBookmark findByAddress( const TQString & address, bool tolerate = false );
/**
* Saves the bookmark file and notifies everyone.
@@ -57,7 +57,7 @@ class KIO_EXPORT KBookmarkManager : public TQObject, public DCOPObject
/**
* Creates a bookmark manager with a path to the bookmarks. By
- * default, it will use the KDE standard dirs to tqfind and create the
+ * default, it will use the KDE standard dirs to find and create the
* correct location. If you are using your own app-specific
* bookmarks directory, you must instantiate this class with your
@@ -152,10 +152,10 @@ public:
* @return the bookmark designated by @p address
* @param address the address belonging to the bookmark you're looking for
- * @param tolerate when true tries to tqfind the most tolerable bookmark position
+ * @param tolerate when true tries to find the most tolerable bookmark position
* @see KBookmark::address
*/